@@ -1,7 +1,7 @@
 """
 	A collection of filesystem related commands.
 """
-import os, re
+import os, re, tempfile
 
 def find( path, 
 	include_dirs = True, include_files = True,
@@ -66,3 +66,46 @@ def find( path,
 					yield whole
 	
 	return filter_func()
+
+class NamedTempFile:
+	"""
+		Creates a temporary file for a 'with' block. The file is deleted when the block exits.
+		This creates the file to ensure it exists/block a race, but does not write anything to
+		it, nor does it keep it open. It is intended for times when you need a named file
+		for subprocesses.
+		
+		Example::
+		
+			with fs.NamedTempFile() as nm:
+				proc.call( "curl http://mortoray.com/ -o {}".format( nm ) )
+				html = open(nm).read()
+				print( len(html) )
+		
+	"""
+	
+	def __init__(self, suffix = None, prefix = None, dir = None ):
+		"""
+			@param suffix: optional suffix for generated filename (a dot '.' is not automatically added, 
+				specifiy it if desired)
+			@param prefix: optional prefix for generated filename
+			@param dir: in which directory, if None then use a system default
+		"""
+		self.args = {
+			'text': False,
+		}
+		if suffix != None:
+			self.args['suffix'] = suffix
+		if prefix != None:
+			self.args['prefix'] = prefix
+		if dir != None:
+			self.args['dir'] = dir
+		
+	def __enter__(self):	
+		(handle, name) = tempfile.mkstemp( **self.args )
+		os.close(handle)
+		self.name = name
+		return name
+		
+	def __exit__(self, type, value, traceback):
+		os.remove(self.name)
+		
\ No newline at end of file
