@@ -212,8 +212,10 @@ def call( cmd, encoding = 'utf-8', shell = False, check_exit_code = True, timeou
 		# Read from subprocess in a thread so the main one can check for the timeout
 		outq = Queue.Queue()
 		def block_read():
-			# collect as lines so if timeout we still have partial output
 			out = proc.stdout.read()
+			# wait before pushing, occassionally read returns prior to process terminating,
+			# thus "poll" would return None
+			proc.wait()
 			outq.put( out )
 			
 		block_thread = threading.Thread( target = block_read )
